@@ -61,7 +61,9 @@ elif os.path.exists("/usr/lib/hubzero/bin/maxwell"):
 else:
   mwprog = ""
 
-if os.path.exists("/etc/mw-client/mw-client.conf"):
+if os.path.exists("/etc/mw-client/mw2-client.conf"):
+  config_file = "/etc/mw-client/mw2-client.conf"
+elif os.path.exists("/etc/mw-client/mw-client.conf"):
   config_file = "/etc/mw-client/mw-client.conf"
 elif os.path.exists("/etc/mw-www/maxwell.conf"):
   config_file = "/etc/mw-www/maxwell.conf"
